===============
Backup-Rotation
===============


.. image:: https://img.shields.io/pypi/v/brotation.svg
        :target: https://pypi.python.org/pypi/brotation

.. image:: https://img.shields.io/travis/asterio.gonzalez/brotation.svg
        :target: https://travis-ci.com/asterio.gonzalez/brotation

.. image:: https://readthedocs.org/projects/brotation/badge/?version=latest
        :target: https://brotation.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Compress and rotate files.


* Free software: MIT license
* Documentation: https://brotation.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
